@@ -67,7 +67,10 @@ class EndpointCollection(BaseInterface, ABC):
         return result
 
     def get_mean(
-        self, value_name: str, endpoints: Optional[List[Type[EndpointWeather]]] = None
+        self,
+        value_name: str,
+        endpoints: Optional[List[Type[EndpointWeather]]] = None,
+        **kwargs: Any
     ) -> int:
         """The get_mean function takes a list of endpoints and a value to
         calculate the mean for the attribute of the objects in the list
